summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/matrix/MatrixView.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/matrix/MatrixView.cpp')
-rw-r--r--src/gui/editors/matrix/MatrixView.cpp72
1 files changed, 36 insertions, 36 deletions
diff --git a/src/gui/editors/matrix/MatrixView.cpp b/src/gui/editors/matrix/MatrixView.cpp
index 3fcf350..9b056d0 100644
--- a/src/gui/editors/matrix/MatrixView.cpp
+++ b/src/gui/editors/matrix/MatrixView.cpp
@@ -903,9 +903,9 @@ void MatrixView::setupActions()
else if (d == crotchetDuration) cut = Key_4;
else if (d == crotchetDuration * 2) cut = Key_2;
- TQString actionName = TQString("snap_%1").tqarg(int((crotchetDuration * 4) / d));
+ TQString actionName = TQString("snap_%1").arg(int((crotchetDuration * 4) / d));
if (d == (crotchetDuration * 3) / 2) actionName = "snap_3";
- new KAction(i18n("Snap to %1").tqarg(label), pixmap, cut, TQT_TQOBJECT(this),
+ new KAction(i18n("Snap to %1").arg(label), pixmap, cut, TQT_TQOBJECT(this),
TQT_SLOT(slotSetSnapFromAction()), actionCollection(),
actionName.ascii());
}
@@ -1099,7 +1099,7 @@ void MatrixView::setViewSize(TQSize s)
void MatrixView::repaintRulers()
{
for (unsigned int i = 0; i != m_propertyViewRulers.size(); i++)
- m_propertyViewRulers[i].first->tqrepaint();
+ m_propertyViewRulers[i].first->repaint();
}
void MatrixView::updateView()
@@ -1196,7 +1196,7 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
getStaff(segment)->positionElements(std::min(startA, startB),
std::max(endA, endB));
} else {
// mark refresh status and then request a tqrepaint
segment.getRefreshStatus
(m_segmentsRefreshStatusIds
[getStaff(segment)->getId()]).
@@ -1213,7 +1213,7 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
getStaff(s->getSegment())->positionElements(startB, endB);
} else {
// mark refresh status and then request a tqrepaint
oldSelection->getSegment().getRefreshStatus
(m_segmentsRefreshStatusIds
@@ -1474,13 +1474,13 @@ MatrixView::slotHoveredOverNoteChanged(int evPitch,
long ms = rt.msec();
TQString msg = i18n("Note: %1 (%2.%3s)")
- .tqarg(TQString("%1-%2-%3-%4")
- .tqarg(TQString("%1").tqarg(bar + 1).rightJustify(3, '0'))
- .tqarg(TQString("%1").tqarg(beat).rightJustify(2, '0'))
- .tqarg(TQString("%1").tqarg(fraction).rightJustify(2, '0'))
- .tqarg(TQString("%1").tqarg(remainder).rightJustify(2, '0')))
- .tqarg(rt.sec)
- .tqarg(TQString("%1").tqarg(ms).rightJustify(3, '0'));
+ .arg(TQString("%1-%2-%3-%4")
+ .arg(TQString("%1").arg(bar + 1).rightJustify(3, '0'))
+ .arg(TQString("%1").arg(beat).rightJustify(2, '0'))
+ .arg(TQString("%1").arg(fraction).rightJustify(2, '0'))
+ .arg(TQString("%1").arg(remainder).rightJustify(2, '0')))
+ .arg(rt.sec)
+ .arg(TQString("%1").arg(ms).rightJustify(3, '0'));
m_hoveredOverAbsoluteTime->setText(msg);
}
@@ -1488,8 +1488,8 @@ MatrixView::slotHoveredOverNoteChanged(int evPitch,
m_haveHoveredOverNote = false;
m_hoveredOverNoteName->setText(i18n("%1 (%2)")
- .tqarg(label.getTQString())
- .tqarg(evPitch));
+ .arg(label.getTQString())
+ .arg(evPitch));
m_pitchRuler->drawHoverNote(evPitch);
}
@@ -1504,7 +1504,7 @@ MatrixView::slotHoveredOverKeyChanged(unsigned int y)
if (evPitch != m_previousEvPitch) {
MidiPitchLabel label(evPitch);
m_hoveredOverNoteName->setText(TQString("%1 (%2)").
- tqarg(label.getTQString()).tqarg(evPitch));
+ arg(label.getTQString()).arg(evPitch));
m_previousEvPitch = evPitch;
}
}
@@ -1529,13 +1529,13 @@ MatrixView::slotHoveredOverAbsoluteTimeChanged(unsigned int time)
// to support Unicode
TQString message = i18n("Time: %1 (%2.%3s)")
- .tqarg(TQString("%1-%2-%3-%4")
- .tqarg(TQString("%1").tqarg(bar + 1).rightJustify(3, '0'))
- .tqarg(TQString("%1").tqarg(beat).rightJustify(2, '0'))
- .tqarg(TQString("%1").tqarg(fraction).rightJustify(2, '0'))
- .tqarg(TQString("%1").tqarg(remainder).rightJustify(2, '0')))
- .tqarg(rt.sec)
- .tqarg(TQString("%1").tqarg(ms).rightJustify(3, '0'));
+ .arg(TQString("%1-%2-%3-%4")
+ .arg(TQString("%1").arg(bar + 1).rightJustify(3, '0'))
+ .arg(TQString("%1").arg(beat).rightJustify(2, '0'))
+ .arg(TQString("%1").arg(fraction).rightJustify(2, '0'))
+ .arg(TQString("%1").arg(remainder).rightJustify(2, '0')))
+ .arg(rt.sec)
+ .arg(TQString("%1").arg(ms).rightJustify(3, '0'));
m_hoveredOverAbsoluteTime->setText(message);
}
@@ -1830,7 +1830,7 @@ void MatrixView::slotInsertNoteFromAction()
} catch (...) {
KMessageBox::sorry
- (this, i18n("Unknown note insert action %1").tqarg(name));
+ (this, i18n("Unknown note insert action %1").arg(name));
return ;
}
@@ -2161,7 +2161,7 @@ MatrixView::initActionsToolbar()
m_velocityCombo = new KComboBox(actionsToolbar);
for (int i = 0; i <= 127; ++i) {
- m_velocityCombo->insertItem(TQString("%1").tqarg(i));
+ m_velocityCombo->insertItem(TQString("%1").arg(i));
}
m_velocityCombo->setCurrentItem(100); //!!! associate with segment
@@ -2236,8 +2236,8 @@ MatrixView::slotChangeHorizontalZoom(int)
{
double zoomValue = m_hZoomSlider->getCurrentSize();
- // m_zoomLabel->setText(i18n("%1%").tqarg(zoomValue*100.0 * 2)); // GROSS HACK - see in matrixstaff.h - BREAKS MATRIX VIEW, see bug 1000595
- m_zoomLabel->setText(i18n("%1%").tqarg(zoomValue*100.0));
+ // m_zoomLabel->setText(i18n("%1%").arg(zoomValue*100.0 * 2)); // GROSS HACK - see in matrixstaff.h - BREAKS MATRIX VIEW, see bug 1000595
+ m_zoomLabel->setText(i18n("%1%").arg(zoomValue*100.0));
MATRIX_DEBUG << "MatrixView::slotChangeHorizontalZoom() : zoom factor = "
<< zoomValue << endl;
@@ -2245,9 +2245,9 @@ MatrixView::slotChangeHorizontalZoom(int)
m_referenceRuler->setHScaleFactor(zoomValue);
if (m_tempoRuler)
- m_tempoRuler->tqrepaint();
+ m_tempoRuler->repaint();
if (m_chordNameRuler)
- m_chordNameRuler->tqrepaint();
+ m_chordNameRuler->repaint();
// Set zoom matrix
//
@@ -2266,7 +2266,7 @@ MatrixView::slotChangeHorizontalZoom(int)
for (unsigned int i = 0; i < m_propertyViewRulers.size(); ++i) {
m_propertyViewRulers[i].first->setHScaleFactor(zoomValue);
- m_propertyViewRulers[i].first->tqrepaint();
+ m_propertyViewRulers[i].first->repaint();
}
if (m_topStandardRuler)
@@ -2721,23 +2721,23 @@ MatrixView::updateViewCaption()
trackPosition = track->getPosition();
setCaption(i18n("%1 - Segment Track #%2 - %3")
- .tqarg(getDocument()->getTitle())
- .tqarg(trackPosition + 1)
- .tqarg(view));
+ .arg(getDocument()->getTitle())
+ .arg(trackPosition + 1)
+ .arg(view));
} else if (m_segments.size() == getDocument()->getComposition().getNbSegments()) {
setCaption(i18n("%1 - All Segments - %2")
- .tqarg(getDocument()->getTitle())
- .tqarg(view));
+ .arg(getDocument()->getTitle())
+ .arg(view));
} else {
setCaption(i18n("%1 - 1 Segment - %2",
"%1 - %n Segments - %2",
m_segments.size())
- .tqarg(getDocument()->getTitle())
- .tqarg(view));
+ .arg(getDocument()->getTitle())
+ .arg(view));
}
}
@@ -1196,7 +1196,7 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
std::max(endA, endB));
} else {
- // mark refresh status and then request a tqrepaint
+ // mark refresh status and then request a repaint
segment.getRefreshStatus
(m_segmentsRefreshStatusIds
@@ -1213,7 +1213,7 @@ void MatrixView::setCurrentSelection(EventSelection* s, bool preview,
getStaff(s->getSegment())->positionElements(startB, endB);
} else {
- // mark refresh status and then request a tqrepaint
+ // mark refresh status and then request a repaint
oldSelection->getSegment().getRefreshStatus
(m_segmentsRefreshStatusIds